pub trait Executor: Send + Sync {
// Required method
fn execute(&mut self, cache: &mut ExecutionState) -> PolarsResult<DataFrame>;
// Provided method
fn is_cache_prefiller(&self) -> bool { ... }
}Expand description
Executors will evaluate physical expressions and collect them in a DataFrame.
Executors have other executors as input. By having a tree of executors we can execute the physical plan until the last executor is evaluated.
Required Methods
fn execute(&mut self, cache: &mut ExecutionState) -> PolarsResult<DataFrame>
Provided Methods
fn is_cache_prefiller(&self) -> bool